@@ -78,13 +78,11 @@ colSpeed="springgreen3"; colForce="blue2"; colPower="tomato2"	#colors
 cols=c(colSpeed,colForce,colPower); lty=rep(1,3)	
 
 
-
-
 #--- user commands ---
 #way A. passing options to a file
 getOptionsFromFile <- function(optionsFile) {
 	optionsCon <- file(optionsFile, 'r')
-	options=readLines(optionsCon,n=29)
+	options=readLines(optionsCon,n=31)
 	close(optionsCon)
 	return (options)
 }
@@ -101,14 +99,26 @@ print(optionsFile)
 
 options=getOptionsFromFile(optionsFile)
 
-print(options)
+#print(options)
 
 OutputData2 = options[4] #currently used to display processing feedback
 SpecialData = options[5]
 OperatingSystem=options[27]
 EncoderConfigurationName = ""
 
-write("(1/5) Starting R", OutputData2)
+English = unlist(strsplit(options[30], "\\;"))
+Translated = unlist(strsplit(options[31], "\\;"))
+
+
+#translate
+translate <- function(englishWord) {
+	if(length(Translated[which(English == englishWord)]) == 0)
+		return (englishWord) #not found, return english word
+	else
+		return(Translated[which(English == englishWord)])
+}
+
+write(paste("(1/5)",translate("Starting R")), OutputData2)
 
 
 # This function converts top curve into bottom curve
@@ -200,10 +210,10 @@ getDisplacementInertialBody <- function(displacement, draw, title)
 		abline(h=0, lty=2, col="gray")
 	
 		lines((1:length(position))/1000,positionPerson/10,lty=1,lwd=2)
-		
+
 		title(title, cex.main=1, font.main=1)
-		mtext("time (s) ",side=1,adj=1,line=-1)
-		mtext("height (cm) ",side=2,adj=1,line=-1)
+		mtext(paste(translate("time"),"(s)"),side=1,adj=1,line=-1)
+		mtext(paste(translate("height"),"(cm)"),side=2,adj=1,line=-1)
 	}
 	return(displacementPerson)
 }
@@ -213,7 +223,7 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 	position.ext=extrema(position)
 	print("at findCurves")
 	print(position.ext)
-	
+
 	start=0; end=0; startH=0
 	tempStart=0; tempEnd=0;
 	#TODO: fer algo per si no es detecta el minindex previ al salt
@@ -227,26 +237,26 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 
 			#tempStart at the end of minindexs
 			#tempStart = position.ext$minindex[i,2]
-			
+
 			#tempStart at the mean of minindexs
 			#this is better because has more data in order to reduceCurveBySpeed
 			#then we get similar results than pyserial_pyper.py
 			tempStart = mean(c(position.ext$minindex[i,1],position.ext$minindex[i,2]))
-			
-			
+
+
 			#end at the mean of maximum values then reduceCurveBySpeed will end it when first speed==0 at right of maxspeed 
 			tempEnd = mean(c(position.ext$maxindex[j,1],position.ext$maxindex[j,2]))
 
 			#end at the first maximum value
 			#tempEnd = position.ext$maxindex[j,1]
-			
+
 			height=position[tempEnd]-position[tempStart]
 			if(height >= min_height) { 
 				start[row] = tempStart
 				end[row]   = tempEnd
 				startH[row]= position[position.ext$minindex[i,1]]		#height at start
 				row=row+1;
-#				if(eccon=="c") { break } #c only needs one result
+				#if(eccon=="c") { break } #c only needs one result
 			} 
 			i=i+1; j=j+1
 		}
@@ -263,7 +273,7 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 		#when saved a row with ec-con, and there's only this curve, extrema doesn't find maxindex
 		if(length(referenceindex) == 0) {
 			start[1] = 1
-			
+
 			if(eccon=="ec" || eccon=="ecS")
 				end[1] = mean(which(position == min(position)))
 			else
@@ -283,7 +293,7 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 		while(j <= length(referenceindex[,1])) {
 			tempStart = mean(c(referenceindex[i,1],referenceindex[i,2]))
 			tempEnd   = mean(c(referenceindex[j,1],referenceindex[j,2]))
-		
+
 			if(eccon=="ec" || eccon=="ecS") {
 				opposite=min(position[tempStart:tempEnd]) #find min value between the two tops
 				mintop=min(c(position[tempStart],position[tempEnd])) #find wich top is lower
@@ -334,10 +344,10 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 		     xlim=c(1,length(position))/1000,		#ms -> s
 		     xlab="",ylab="",axes=T,
 		     lty=lty,col=col) 
-		
+
 		title(title, cex.main=1, font.main=1)
-		mtext("time (s) ",side=1,adj=1,line=-1)
-		mtext("height (cm) ",side=2,adj=1,line=-1)
+		mtext(paste(translate("time"),"(s)"),side=1,adj=1,line=-1)
+		mtext(paste(translate("height"),"(cm)"),side=2,adj=1,line=-1)
 	}
 	return(as.data.frame(cbind(start,end,startH)))
 }
@@ -609,8 +619,7 @@ print(c(" |Ms|",round(max(abs(speed$y)),5)," |Ma|",round(max(abs(accel$y)),5)))
 	concentric = 0
 	propulsiveEnd = 0
 
-#print("at kinematicsF eccon==")
-#print(eccon)
+print(c("at kinematicsF eccon==", eccon))
 
 	#search propulsiveEnd
 	if(isPropulsive) {
@@ -622,7 +631,7 @@ print(c(" |Ms|",round(max(abs(speed$y)),5)," |Ma|",round(max(abs(accel$y)),5)))
 			eccentric = phases$eccentric
 			isometric = phases$isometric
 			concentric = phases$concentric
-			propulsiveEnd = findPropulsiveEnd(accel$y,concentric)
+			propulsiveEnd = length(eccentric) + length(isometric) + findPropulsiveEnd(accel$y,concentric)
 		} else if(eccon=="e") {
 			#not eccon="e" because not propulsive calculations on eccentric
 		} else { #ecS
@@ -687,9 +696,11 @@ kinematicRanges <- function(singleFile, displacement, curves,
 			    massBody, massExtra, exercisePercentBodyWeight,
 			    encoderConfigurationName,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
 			    smoothingsEC, smoothingOneC, g, eccon, isPropulsive) {
+
 	n=length(curves[,1])
 	maxSpeedy=0; maxAccely=0; maxForce=0; maxPower=0
 	myEccon = eccon
+
 	for(i in 1:n) { 
 		myMassBody = massBody
 		myMassExtra = massExtra
@@ -718,7 +729,7 @@ kinematicRanges <- function(singleFile, displacement, curves,
 			myInertiaMomentum = curves[i,16]
 			myGearedDown = curves[i,17]
 		}
-
+	
 		kn=kinematicsF(displacement[curves[i,1]:curves[i,2]],
 			       myMassBody, myMassExtra, myExPercentBodyWeight,
 			       myEncoderConfigurationName,myDiameter,myDiameterExt,myAnglePush,myAngleWeight,myInertiaMomentum,myGearedDown,
@@ -733,6 +744,7 @@ kinematicRanges <- function(singleFile, displacement, curves,
 		if(max(abs(kn$power)) > maxPower)
 			maxPower = max(abs(kn$power))
 	}
+
 	return(list(
 		speedy=c(-maxSpeedy,maxSpeedy),
 		accely=c(-maxAccely,maxAccely),
@@ -753,13 +765,14 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	meanSpeedC = 0
 	meanPowerE = 0
 	meanPowerC = 0
-	
+
 	smoothing = 0
 	if(eccon == "c")
 		smoothing = smoothingOneC
 	else
 		smoothing = smoothingOneEC
 
+
 	#eccons ec and ecS is the same here (only show one curve)
 	#receive data as cumulative sum
 	lty=c(1,1,1)
@@ -873,9 +886,9 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	#	segments(x0=speed.ext$maxindex,y0=0,x1=speed.ext$maxindex,y1=speed$y[speed.ext$maxindex],col=cols[1])
 
 	#declare variables:
-	eccentric=0
-	isometric=0
-	concentric=0
+	eccentric=NULL
+	isometric=NULL
+	concentric=NULL
 
 	if(eccon=="c") {
 		concentric=1:length(displacement)
@@ -920,8 +933,8 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			      side=1,at=min(isometric),adj=1,cex=.8,col=cols[1])
 			mtext(text=paste(" ", round(max(isometric),1),sep=""), 
 			      side=1,at=max(isometric),adj=0,cex=.8,col=cols[1])
-			mtext(text="eccentric ",side=3,at=max(eccentric),cex=.8,adj=1,col=cols[1],line=.5)
-			mtext(text=" concentric ",side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
+			mtext(text=paste(translate("eccentric")," ",sep=""),side=3,at=max(eccentric),cex=.8,adj=1,col=cols[1],line=.5)
+			mtext(text=paste(" ",translate("concentric"),sep=""),side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
 		}
 	}
 		
@@ -1028,14 +1041,6 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	power = dynamics$power
 
 
-#print(c(knRanges$accely, max(accel$y), min(accel$y)))
-#	force <- mass*accel$y
-#	if(isJump)
-#		force <- mass*(accel$y+g)	#g:9.81 (used when movement is against gravity)
-
-#print("MAXFORCE!!!!!")
-#print(max(force))
-
 	if(draw & showForce) {
 		ylim=c(-max(abs(range(force))),max(abs(range(force))))	 #put 0 in the middle
 		if(knRanges[1] != "undefined")
@@ -1061,15 +1066,16 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	if(draw & (!superpose || (superpose & highlight)) & exercisePercentBodyWeight == 100) {
 		weight=mass*g
 		abline(h=weight,lty=1,col=cols[2]) #body force, lower than this, person in the air (in a jump)
+		text(x=length(force),y=weight,labels=paste(translate("Weight"),"(N)"),cex=.8,adj=c(.5,0),col=cols[2])
 
 		#define like this, because if eccentric == 0, length(eccentric) == 1
-		#and if eccentric is NULL, then length(eccentric == 0), but max(eccentric) produces error
-		if(eccentric == 0)
+		#and if eccentric is NULL, then length(eccentric) == 0, but max(eccentric) produces error
+		if(length(eccentric) == 0)
 			length_eccentric = 0
 		else
 			length_eccentric = length(eccentric)
 
-		if(isometric == 0)
+		if(length(isometric) == 0)
 			length_isometric = 0
 		else
 			length_isometric = length(isometric)
@@ -1077,69 +1083,39 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 		#takeoff = max(which(force>=weight))
 		#takeoff = min(which(force[concentric]<=weight)) + length_eccentric + length_isometric
-		takeoff = min(which(force[concentric]<=0)) + length_eccentric + length_isometric
-		abline(v=takeoff,lty=1,col=cols[2]) 
-		mtext(text="land ",side=3,at=takeoff,cex=.8,adj=1,col=cols[2])
-		mtext(text=" air ",side=3,at=takeoff,cex=.8,adj=0,col=cols[2])
-		text(x=length(force),y=weight,labels="Weight (N)",cex=.8,adj=c(.5,0),col=cols[2])
+
+		takeoff = -1
+		if(length(which(force[concentric] <= 0)) == 0)
+			takeoff = -1
+		else {
+			takeoff = min(which(force[concentric]<=0)) + length_eccentric + length_isometric
+			abline(v=takeoff,lty=1,col=cols[2]) 
+			mtext(text=paste(translate("land")," ",sep=""),side=3,at=takeoff,cex=.8,adj=1,col=cols[2])
+			mtext(text=paste(" ", translate("air"), " ",sep=""),side=3,at=takeoff,cex=.8,adj=0,col=cols[2])
+		}
 
 		if(eccon=="ec") {
+			landing = -1
 			#landing = min(which(force>=weight))
-			landing = max(which(force[eccentric]<=weight))
-			abline(v=landing,lty=1,col=cols[2]) 
-			mtext(text="air ",side=3,at=landing,cex=.8,adj=1,col=cols[2])
-			mtext(text=" land ",side=3,at=landing,cex=.8,adj=0,col=cols[2])
-		}
 		
-		mtext(text=paste("jump height =", 
-				 (position[concentric[length(concentric)]] - 
-				  position[concentric[(takeoff - length_eccentric - length_isometric)]])/10,
-				 "cm",sep=" "),
-		      side=3, at=( takeoff + (length_eccentric + length(concentric)) )/2,
-		      cex=.8,adj=0.5,col=cols[2])
-	}
-	#forceToBodyMass <- force - weight
-	#force.ext=extrema(forceToBodyMass)
-	#abline(v=force.ext$cross[,1],lty=3,col=cols[2]) #body force, lower than this, person in the air (in a jump)
-	#text(x=(mean(force.ext$cross[1,1],force.ext$cross[1,2])+mean(force.ext$cross[2,1],force.ext$cross[2,2]))/2, y=weight, 
-	#		labels=paste("flight time:", 
-	#			mean(force.ext$cross[2,1],force.ext$cross[2,2])-mean(force.ext$cross[1,1],force.ext$cross[1,2]),"ms"), 
-	#		col=cols[2], cex=.8, adj=c(0.5,0))
-
-	#power #normalment m=massa barra + peses: 	F=m*a #com es va contra gravetat: 		F=m*a+m*g  	F=m*(a+g) #g sempre es positiva. a es negativa en la baixada de manera que en caiguda lliure F=0 #cal afegir la resistencia del encoder a la força #Potència	P=F*V #si es treballa amb el pes corporal, cal afegir-lo
-
-	#F=m*a		#bar
-	#F=(m*a)+(m*g) #jump m*(a+g) F=m*0
-
-
-
-	#power = NULL
-
-	#if(inertialType == "li" || inertialType == "ri") {
-		#Explanation rotatory encoder on inertial machine
-		#speed$y comes in mm/ms, is the same than m/s
-		#speedw in meters:
-	 #	speedw <- speed$y / diameter #m radius
-		#accel$y comes in meters
-		#accelw in meters:
-	#	accelw <- accel$y / diameter
-
-		#power = power to the inertial machine (rotatory disc) + power to the displaced body mass (lineal)
-		#power = ( inertia momentum * angular acceleration * angular velocity ) + mass(includes extra weight if any) * accel$y * speed$y  
-		#abs(speedw) because disc is rolling in the same direction and we don't have to make power to change it
-	#	power <- inertiaMomentum * accelw * speedw + mass * (accel$y +g) * speed$y
+			if(length(which(force[eccentric] <= weight)) == 0)
+				landing = -1
+			else {
+				landing = max(which(force[eccentric]<=weight))
+				abline(v=landing,lty=1,col=cols[2]) 
+				mtext(text=paste(translate("air")," ",sep=""),side=3,at=landing,cex=.8,adj=1,col=cols[2])
+				mtext(text=paste(" ",translate("land")," ",sep=""),side=3,at=landing,cex=.8,adj=0,col=cols[2])
+			}
+		}
 	
-		#print("at Paint")	
-		#print(c("mass",mass))
-		#print(c("speed$y",speed$y))
-		#print(c("speedw",speedw))
-		#print(c("accel$y",accel$y))
-		#print(c("accelw",accelw))
-		#print(c("power",power))
-	#}
-	#else #(inertialType == "")
-	#	power <- force*speed$y
-
+		if(takeoff != -1)	
+			mtext(text=paste(translate("jump height"),"=", 
+					 (position[concentric[length(concentric)]] - 
+					  position[concentric[(takeoff - length_eccentric - length_isometric)]])/10,
+					 "cm",sep=" "),
+			      side=3, at=( takeoff + (length_eccentric + length(concentric)) )/2,
+			      cex=.8,adj=0.5,col=cols[2])
+	}
 
 
 	if(draw & showPower) {
@@ -1220,35 +1196,35 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	#legend, axes and title
 	if(draw) {
 		if(legend & showAxes) {
-			legendText=c("Distance (mm)")
+			legendText=c(paste(translate("Distance"),"(mm)"))
 			lty=c(1)
 			lwd=c(2)
 			colors=c("black") 
 			ncol=1
 
 			if(showSpeed) {
-				legendText=c(legendText, "Speed (m/s)")
+				legendText=c(legendText, paste(translate("Speed"),"(m/s)"))
 				lty=c(lty,1)
 				lwd=c(lwd,2)
 				colors=c(colors,cols[1]) 
 				ncol=ncol+1
 			}
 			if(showAccel) {
-				legendText=c(legendText, "Accel. (m/s²)")
+				legendText=c(legendText, paste(translate("Accel."),"(m/s²)"))
 				lty=c(lty,1)
 				lwd=c(lwd,2)
 				colors=c(colors,"magenta") 
 				ncol=ncol+1
 			}
 			if(showForce) {
-				legendText=c(legendText, "Force (N)")
+				legendText=c(legendText, paste(translate("Force"),"(N)"))
 				lty=c(lty,1)
 				lwd=c(lwd,2)
 				colors=c(colors,cols[2]) 
 				ncol=ncol+1
 			}
 			if(showPower) {
-				legendText=c(legendText, "Power (W)")
+				legendText=c(legendText, paste(translate("Power"),"(W)"))
 				lty=c(lty,1)
 				lwd=c(lwd,2)
 				colors=c(colors,cols[3]) 
@@ -1271,8 +1247,8 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			       cex=1, bg="white", ncol=ncol, bty="n", plot=T, xpd=NA)
 		}
 		if(showLabels) {
-			mtext("time (ms) ",side=1,adj=1,line=-1,cex=.9)
-			mtext("height (mm) ",side=2,adj=1,line=-1,cex=.9)
+			mtext(paste(translate("time"),"(ms)"),side=1,adj=1,line=-1,cex=.9)
+			mtext(paste(translate("height"),"(mm)"),side=2,adj=1,line=-1,cex=.9)
 		}
 	}
 }
@@ -1308,12 +1284,12 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 	#when eccon != c show always ABS power
 	#peakPower is always ABS
 	if(Eccon == "c") {
-		powerName = "Power"
-		peakPowerName = "Peak Power (ABS)"
+		powerName = translate("Power")
+		peakPowerName = paste(translate("Peak Power"),"(ABS)")
 	}
 	else {
-		powerName = "Power (ABS)"
-		peakPowerName = "Peak Power (ABS)"
+		powerName = paste(translate("Power"),"(ABS)")
+		peakPowerName = paste(translate("Peak Power"),"(ABS)")
 	}
 
 	print("powerData")
@@ -1334,11 +1310,11 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 	par(mar=c(2.5, 4, 5, marginRight))
 	bp <- barplot(powerData,beside=T,col=pafColors[1:2],width=c(1.4,.6),
 			names.arg=paste(myNums,"\n",load,sep=""),xlim=c(1,n*3+.5),cex.name=0.9,
-			xlab="",ylab="Power (W)", 
+			xlab="",ylab=paste(translate("Power"),"(W)"), 
 			ylim=c(lowerY,max(powerData)), xpd=FALSE) #ylim, xpd = F,  makes barplot starts high (compare between them)
 	title(main=title,line=-2,outer=T)
-	mtext("Curve \nLoad ",side=1,at=1,adj=1,line=1,cex=.9)
-	
+	mtext(paste(translate("Curve")," \n",translate("Load")," ",sep=""),side=1,at=1,adj=1,line=1,cex=.9)
+
 	axisLineRight=0
 
 	#time to peak power
@@ -1355,7 +1331,7 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 			     axes=F,xlab="",ylab="",col=pafColors[3])
 
 		axis(4, col=pafColors[3], line=axisLineRight,padj=-.5)
-		mtext("Time to peak power (ms)", side=4, line=(axisLineRight-1))
+		mtext(paste(translate("Time to Peak Power"),"(ms)"), side=4, line=(axisLineRight-1))
 		axisLineRight = axisLineRight +3
 	}
 
@@ -1368,7 +1344,7 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 		abline(h=min(height),lty=2, col="green")
 		#text(max(bp[,2]),max(height),max(height),adj=c(0,.5),cex=0.8)
 		axis(4, col="green", line=axisLineRight, padj=-.5)
-		mtext("Range (cm)", side=4, line=(axisLineRight-1))
+		mtext(paste(translate("Range"),"(cm)"), side=4, line=(axisLineRight-1))
 		axisLineRight = axisLineRight +3
 
 		for(i in unique(load)) { 
@@ -1397,14 +1373,14 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 	graphColors=c(pafColors[1],pafColors[2])
 
 	if(showTTPP) {
-		legendText = c(legendText, "Time to Peak Power    ")
+		legendText = c(legendText, paste(translate("Time to Peak Power"),"    ",sep=""))
 		lty=c(lty,1)
 		lwd=c(lwd,2)
 		pch=c(pch,NA)
 		graphColors=c(graphColors,pafColors[3])
 	}
 	if(showRange) {
-		legendText = c(legendText, "Range")
+		legendText = c(legendText, translate("Range"))
 		lty=c(lty,1)
 		lwd=c(lwd,2)
 		pch=c(pch,NA)
@@ -1448,13 +1424,13 @@ findPosInPaf <- function(var, option) {
 
 addUnits <- function (var) {
 	if(var == "Speed")
-		return ("Speed (m/s)")
+		return (paste(translate("Speed"),"(m/s)"))
 	else if(var == "Power")
-		return ("Power (W)")
+		return (paste(translate("Power"),"(W)"))
 	else if(var == "Load") #or Mass
-		return ("Load (Kg)")
+		return (paste(translate("Load"),"(Kg)"))
 	else if(var == "Force")
-		return ("Force (N)")
+		return (paste(translate("Force"),"(N)"))
 
 	return(var)
 }
@@ -1540,7 +1516,7 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 
 			if(is.na(c.x)) {
 				plot(0,0,type="n",axes=F,xlab="",ylab="")
-				text(x=0,y=0,"Not enough data.",cex=1.5)
+				text(x=0,y=0,translate("Not enough data."),cex=1.5)
 				dev.off()
 				write("1RM;-1", SpecialData)
 				write("", outputData1)
@@ -1667,7 +1643,7 @@ paint1RMBadillo2010 <- function (paf, title, outputData1) {
 
 	if(length(curvesSpeedInIntervalPos) == 0) {
 		plot(0,0,type="n",axes=F,xlab="",ylab="")
-		text(x=0,y=0,"Not enough data.",cex=1.5)
+		text(x=0,y=0,translate("Not enough data."),cex=1.5)
 		dev.off()
 		write("1RM;-1", SpecialData)
 		write("", outputData1)
@@ -1677,13 +1653,16 @@ paint1RMBadillo2010 <- function (paf, title, outputData1) {
 	par(mar=c(6,5,3,4))
 
 	plot(curvesLoad,curvesSpeed, type="p",
-	     main=paste(title, "1RM prediction"),
-	     sub="\nConcentric mean speed on bench press 1RM is 0.185m/s. Estimated percentual load = 8.4326 * speed ^2 - 73.501 * speed + 112.33\nAdapted from Gonzalez-Badillo, Sanchez-Medina (2010)",
+	     main=paste(title, "1RM", translate("prediction")),
+	     sub=paste("\n",translate("Concentric mean speed on bench press 1RM =")," 0.185m/s.",
+		      translate("Estimated percentual load ="),
+		      " 8.4326 * ", translate("speed"), " ^2 - 73.501 * ", translate("speed"), " + 112.33\n",
+		      translate("Adapted from")," Gonzalez-Badillo, Sanchez-Medina (2010)"),
 	     xlim=c(min(curvesLoad),max(loadCalc[curvesSpeedInIntervalPos])),
 	     ylim=c(miny,maxy), xlab="", ylab="",axes=T)
 
 	mtext(side=1,line=2,"Kg")
-	mtext(side=2,line=3,"Mean speed in concentric propulsive phase (m/s)")
+	mtext(side=2,line=3,paste(translate("Mean speed in concentric propulsive phase"),"(m/s)"))
 	mtext(side=4,line=2,"1RM (%)")
 
 	abline(h=msp, lty=2, col="gray")
@@ -1942,7 +1921,7 @@ quitIfNoData <- function(n, curves, outputData1) {
 	#if not found curves with this data, plot a "sorry" message and exit
 	if(n == 1 & curves[1,1] == 0 & curves[1,2] == 0) {
 		plot(0,0,type="n",axes=F,xlab="",ylab="")
-		text(x=0,y=0,"Sorry, no curves matched your criteria.",cex=1.5)
+		text(x=0,y=0,translate("Sorry, no curves matched your criteria."),cex=1.5)
 		dev.off()
 		write("", outputData1)
 		quit()
@@ -2002,6 +1981,13 @@ doProcess <- function(options) {
 	Height=as.numeric(options[24])
 	DecimalSeparator=options[25]
 	Title=options[26]
+
+	print(c("1 Title=",Title))
+	#unicoded titles arrive here like this "\\", convert to "\", as this is difficoult, do like this:
+	#http://stackoverflow.com/a/17787736
+	Title=parse(text = paste0("'", Title, "'"))
+	print(c("1 Title=",Title))
+
 	OperatingSystem=options[27]	#if this changes, change it also at start of this R file
 	#IMPORTANT, if this grows, change the readLines value on getOptionsFromFile
 
@@ -2013,6 +1999,11 @@ doProcess <- function(options) {
 	if(scriptTwo != "none")
 		source(scriptTwo)
 
+	#options 30 and 31 is assigned on the top of the file to be available in all functions
+	#print(options[30])
+	#print(options[31])
+
+
 	print(File)
 	print(OutputGraph)
 	print(OutputData1)
@@ -2029,6 +2020,7 @@ doProcess <- function(options) {
 		inertialType = analysisOptionsTemp[2] #values: "" || "li" || "ri"
 	}
 
+
 	#inertial cannot be propulsive
 	if(isInertial(EncoderConfigurationName))
 		isPropulsive = FALSE
@@ -2224,12 +2216,11 @@ doProcess <- function(options) {
 		
 		print("curves")
 		print(curves)
-		
+	
 		#find SmoothingsEC
 		SmoothingsEC = findSmoothingsEC(displacement, curves, Eccon, SmoothingOneC)
 	} else {	#singleFile == True. reads a signal file
 		displacement=scan(file=File,sep=",")
-			
 		#if data file ends with comma. Last character will be an NA. remove it
 		#this removes all NAs
 		displacement  = displacement[!is.na(displacement)]
@@ -2247,7 +2238,7 @@ doProcess <- function(options) {
 
 		if(length(displacement)==0) {
 			plot(0,0,type="n",axes=F,xlab="",ylab="")
-			text(x=0,y=0,"Encoder is not connected.",cex=1.5)
+			text(x=0,y=0,translate("Encoder is not connected."),cex=1.5)
 			dev.off()
 			write("", OutputData1)
 			quit()
@@ -2330,15 +2321,15 @@ doProcess <- function(options) {
 		     		xlab="",ylab="",axes=F)
 			
 			if(isInertial(EncoderConfigurationName))
-				mtext("body speed ",side=4,adj=1,line=-1,col="green2",cex=.8)
+				mtext(translate("body speed"),side=4,adj=1,line=-1,col="green2",cex=.8)
 			else
-				mtext("speed ",side=4,adj=1,line=-1,col="green2")
+				mtext(translate("speed"),side=4,adj=1,line=-1,col="green2")
 
 			abline(h=0,lty=2,col="gray")
 		}
 	}
 
-	write("(4/5) Curves processed", OutputData2)
+	write(paste("(4/5)",translate("Curves processed")), OutputData2)
 
 	if(Analysis=="single") {
 		if(Jump>0) {
@@ -2372,7 +2363,6 @@ doProcess <- function(options) {
 				myInertiaMomentum = curves[Jump,16]
 				myGearedDown = curves[Jump,17]
 			}
-			
 			myCurveStr = paste("curve=", Jump, ", ", myMassExtra, "Kg", sep="")
 		
 			#don't do this, because on inertial machines string will be rolled to machine and not connected to the body
@@ -2381,8 +2371,9 @@ doProcess <- function(options) {
 			#	myEccon="c"
 			#}
 
+
 			paint(displacement, myEccon, myStart, myEnd,"undefined","undefined",FALSE,FALSE,
-			      1,curves[Jump,3],SmoothingsEC[as.numeric(Jump)],SmoothingOneC,myMassBody,myMassExtra,
+			      1,curves[Jump,3],SmoothingsEC[1],SmoothingOneC,myMassBody,myMassExtra,
 			      myEncoderConfigurationName,myDiameter,myDiameterExt,myAnglePush,myAngleWeight,myInertiaMomentum,myGearedDown,
 			      paste(Title, " ", Analysis, " ", myEccon, " ", myCurveStr, sep=""),
 			      "", #subtitle
@@ -2670,7 +2661,8 @@ doProcess <- function(options) {
 
 			if(n < 24) {
 				plot(0,0,type="n",axes=F,xlab="",ylab="")
-				text(x=0,y=0,"Not enough data.\nNeed 6 jumps and 4 phases for each jump (ecc,con,ecc,con).",cex=1.5)
+				text(x=0,y=0,paste(translate("Not enough data."), "\n",
+						   translate("Need 6 jumps and 4 phases for each jump")," (ecc,con,ecc,con)."),cex=1.5)
 				dev.off()
 				write("", OutputData1)
 				quit()
@@ -2846,16 +2838,16 @@ doProcess <- function(options) {
 	if(Analysis != "exportCSV")
 		dev.off()
 
-	write("(5/5) R tasks done", OutputData2)
+	write(paste("(5/5)",translate("R tasks done")), OutputData2)
 
 	warnings()
 }
 
-write("(2/5) Loading libraries", OutputData2)
+write(paste("(2/5)",translate("Loading libraries")), OutputData2)
 
 loadLibraries(OperatingSystem)
 	
-write("(3/5) Starting process", OutputData2)
+write(paste("(3/5)",translate("Starting process")), OutputData2)
 
 doProcess(options)
 
