@@ -370,6 +370,8 @@ public class Constants
 	public static string FileNameOpen = "gtk-open.png";
 	public static string FileNameOpen1 = "gtk-open-1.png";
 	public static string FileNameOpenPlus = "gtk-open-plus.png";
+	public static string FileNameCSVHeadersIcon = "import-csv-headers.png";
+	public static string FileNameCSVNoHeadersIcon = "import-csv-noheaders.png";
 
 	public static string FileNameJumps = "stock_up.png";
 	public static string FileNameJumpsRJ = "stock_up_down.png";
@@ -386,6 +388,9 @@ public class Constants
 	public static string FileNameContactPlatformModular = "modular_platform_with_chronopic.jpg";
 	public static string FileNameInfrared = "infrared.jpg";
 	
+	public static string FileNameEncoderAnalyzeCurrentSignalIcon = "encoder-analyze-current-signal.png";
+	public static string FileNameEncoderAnalyzeSavedCurvesIcon = "encoder-analyze-saved-curves.png";
+
 	public static string FileNameEncoderAnalyzePowerbarsIcon = "encoder-analyze-powerbars.png";
 	public static string FileNameEncoderAnalyzeCrossIcon = "encoder-analyze-cross.png";
 	public static string FileNameEncoderAnalyzeSideIcon = "encoder-analyze-side.png";
@@ -395,6 +400,16 @@ public class Constants
 	public static string FileNameEncoderAnalyzeEcconTogetherIcon = "encoder-analyze-eccon-together.png";
 	public static string FileNameEncoderAnalyzeEcconSeparatedIcon = "encoder-analyze-eccon-separated.png";
 	
+	public static string FileNameEncoderAnalyzeSpeedIcon = "encoder-analyze-speed.png";
+	public static string FileNameEncoderAnalyzeAccelIcon = "encoder-analyze-accel.png";
+	public static string FileNameEncoderAnalyzeForceIcon = "encoder-analyze-force.png";
+	public static string FileNameEncoderAnalyzePowerIcon = "encoder-analyze-power.png";
+	
+	public static string FileNameEncoderAnalyzeMeanIcon = "encoder-analyze-mean.png";
+	public static string FileNameEncoderAnalyzeMaxIcon = "encoder-analyze-max.png";
+	public static string FileNameEncoderAnalyzeRangeIcon = "encoder-analyze-range.png";
+	public static string FileNameEncoderAnalyzeTimeToPPIcon = "encoder-analyze-time-to-pp.png";
+	
 	//30 colors defined
 	//see als UtilGtk that's not used by the server
 	public static string [] Colors = {
@@ -717,4 +732,92 @@ public class Constants
 	}	
 	
 	public enum Status { ERROR, UNSTARTED, OK}	
+	
+	/*
+	 * Attention: this will be separated by ';', then no ';' sign can be here
+	 * No "\n" can be here also
+	 * check that this list has same elements than below list
+	 */
+	public static string [] EncoderEnglishWords = {
+		"jump",
+		"body speed",
+		"speed",
+		"Speed",
+		"Accel.",
+		"Force",
+		"Power",
+		"Peak Power",
+		"Distance",
+		"Time to Peak Power",
+		"time",
+		"Range",
+		"height",
+		"Weight",
+		"Load",
+		"eccentric",
+		"concentric",
+		"land",
+		"air",
+		"jump height",
+		"Curve",
+		"Not enough data.",
+		"Encoder is not connected.", 
+		"prediction",
+		"Concentric mean speed on bench press 1RM =",
+		"Estimated percentual load =",
+		"Adapted from",
+		"Mean speed in concentric propulsive phase",
+		"Sorry, no curves matched your criteria.",
+		"Need 6 jumps and 4 phases for each jump",
+		"Starting R",
+		"Loading libraries",
+		"Starting process",
+		"Curves processed",
+		"R tasks done"
+	};
+	/*
+	 * written here in order to be translated
+	 * Attention: this will be separated by ';', then no ';' sign can be here
+	 * No "\n" can be here also
+	 * if translators add one, it will be converted to ','
+	 * if translators add a "\n", it will be converted to " "
+	 * check that this list has same elements than above list
+	 */
+	public static string [] EncoderTranslatedWords = {
+		Catalog.GetString("jump"),
+		Catalog.GetString("body speed"),
+		Catalog.GetString("speed"),
+		Catalog.GetString("Speed"),
+		Catalog.GetString("Accel."),
+		Catalog.GetString("Force"),
+		Catalog.GetString("Power"),
+		Catalog.GetString("Peak Power"),
+		Catalog.GetString("Distance"),
+		Catalog.GetString("Time to Peak Power"),
+		Catalog.GetString("time"),
+		Catalog.GetString("Range"),
+		Catalog.GetString("height"),
+		Catalog.GetString("Weight"),
+		Catalog.GetString("Load"),
+		Catalog.GetString("eccentric"),
+		Catalog.GetString("concentric"),
+		Catalog.GetString("land"),
+		Catalog.GetString("air"),
+		Catalog.GetString("jump height"),
+		Catalog.GetString("Curve"),
+		Catalog.GetString("Not enough data."),
+		Catalog.GetString("Encoder is not connected."),
+		Catalog.GetString("prediction"),
+		Catalog.GetString("Concentric mean speed on bench press 1RM is"),
+		Catalog.GetString("Estimated percentual load ="),
+		Catalog.GetString("Adapted from"),
+		Catalog.GetString("Mean speed in concentric propulsive phase"),
+		Catalog.GetString("Sorry, no curves matched your criteria."),
+		Catalog.GetString("Need 6 jumps and 4 phases for each jump"),
+		Catalog.GetString("Starting R"),
+		Catalog.GetString("Loading libraries"),
+		Catalog.GetString("Starting process"),
+		Catalog.GetString("Curves processed"),
+		Catalog.GetString("R tasks done")
+	};
 }
