@@ -1040,47 +1040,6 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.Label extra_window_label_jumps_rj_no_options;
 	[Widget] Gtk.CheckButton checkbutton_allow_finish_rj_after_time;
 
-	//labels notebook_execute	
-	[Widget] Gtk.Label label_extra_window_radio_jump_free;
-	[Widget] Gtk.Label label_extra_window_radio_jump_sj;
-	[Widget] Gtk.Label label_extra_window_radio_jump_sjl;
-	[Widget] Gtk.Label label_extra_window_radio_jump_cmj;
-	[Widget] Gtk.Label label_extra_window_radio_jump_cmjl;
-	[Widget] Gtk.Label label_extra_window_radio_jump_slcmj;
-	[Widget] Gtk.Label label_extra_window_radio_jump_abk;
-	[Widget] Gtk.Label label_extra_window_radio_jump_dj;
-	[Widget] Gtk.Label label_extra_window_radio_jump_rocket;
-	[Widget] Gtk.Label label_extra_window_radio_jump_takeoff;
-	[Widget] Gtk.Label label_extra_window_radio_jump_more;
-
-	//radio notebook_execute	
-	[Widget] Gtk.RadioButton extra_window_radio_jump_free;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_sj;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_sjl;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_cmj;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_cmjl;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_slcmj;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_abk;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_dj;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_rocket;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_takeoff;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_more;
-	
-	[Widget] Gtk.Label label_extra_window_radio_jump_rj_j;
-	[Widget] Gtk.Label label_extra_window_radio_jump_rj_t;
-	[Widget] Gtk.Label label_extra_window_radio_jump_rj_unlimited;
-	[Widget] Gtk.Label label_extra_window_radio_jump_rj_hexagon;
-	[Widget] Gtk.Label label_extra_window_radio_jump_rj_more;
-
-	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_j;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_t;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_unlimited;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_hexagon;
-	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_more;
-
-	//selected test labels	
-	[Widget] Gtk.Label extra_window_jumps_label_selected;
-	[Widget] Gtk.Label extra_window_jumps_rj_label_selected;
 	
 	//for RunAnalysis
 	//but will be used and recorded with "fall"
@@ -1088,7 +1047,7 @@ partial class ChronoJumpWindow
 
 	//jumps
 	string extra_window_jumps_option = "Kg";
-	double extra_window_jumps_weight = 20;
+	//double extra_window_jumps_weight = 20;
 	double extra_window_jumps_fall = 20;
 	bool extra_window_jumps_arms = false;
 	
@@ -1104,17 +1063,9 @@ partial class ChronoJumpWindow
 	
 	private void on_extra_window_jumps_test_changed(object o, EventArgs args)
 	{
-		if(extra_window_radio_jump_free.Active) currentJumpType = new JumpType("Free");
-		else if(extra_window_radio_jump_sj.Active) currentJumpType = new JumpType("SJ");
-		else if(extra_window_radio_jump_sjl.Active) currentJumpType = new JumpType("SJl");
-		else if(extra_window_radio_jump_cmj.Active) currentJumpType = new JumpType("CMJ");
-		else if(extra_window_radio_jump_cmjl.Active) currentJumpType = new JumpType("CMJl");
-		else if(extra_window_radio_jump_slcmj.Active) currentJumpType = new JumpType("slCMJ");
-		else if(extra_window_radio_jump_abk.Active) currentJumpType = new JumpType("ABK");
-		else if(extra_window_radio_jump_dj.Active) currentJumpType = new JumpType("DJ");
-		else if(extra_window_radio_jump_rocket.Active) currentJumpType = new JumpType("Rocket");
-		else if(extra_window_radio_jump_takeoff.Active) currentJumpType = new JumpType(Constants.TakeOffName);
-
+		string jumpEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_jumps), selectJumpsString);
+		currentJumpType = new JumpType(jumpEnglishName);
+		
 		extra_window_jumps_initialize(currentJumpType);
 	}
 	
@@ -1122,21 +1073,17 @@ partial class ChronoJumpWindow
 	{
 		previousJumpType = currentJumpType;
 
-		if(extra_window_radio_jump_more.Active) {
-			jumpsMoreWin = JumpsMoreWindow.Show(app1, true, currentJumpType.Name);
-			jumpsMoreWin.Button_accept.Clicked += new EventHandler(on_more_jumps_accepted);
-			jumpsMoreWin.Button_cancel.Clicked += new EventHandler(on_more_jumps_cancelled);
-			jumpsMoreWin.Button_selected.Clicked += new EventHandler(on_more_jumps_draw_image_test);
-		}
+		jumpsMoreWin = JumpsMoreWindow.Show(app1, true);
+		jumpsMoreWin.Button_accept.Clicked += new EventHandler(on_more_jumps_accepted);
+		jumpsMoreWin.Button_cancel.Clicked += new EventHandler(on_more_jumps_cancelled);
+		jumpsMoreWin.Button_selected.Clicked += new EventHandler(on_more_jumps_update_test);
 	}
 	
 	private void on_extra_window_jumps_rj_test_changed(object o, EventArgs args)
 	{
-		if(extra_window_radio_jump_rj_j.Active) currentJumpRjType = new JumpType("RJ(j)");
-		else if(extra_window_radio_jump_rj_t.Active) currentJumpRjType = new JumpType("RJ(t)");
-		else if(extra_window_radio_jump_rj_unlimited.Active) currentJumpRjType = new JumpType("RJ(unlimited)");
-		else if(extra_window_radio_jump_rj_hexagon.Active) currentJumpRjType = new JumpType("RJ(hexagon)");
-
+		string jumpEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_jumps_rj), selectJumpsRjString);
+		currentJumpRjType = new JumpType(jumpEnglishName);
+		
 		extra_window_jumps_rj_initialize(currentJumpRjType);
 	}
 
@@ -1144,19 +1091,15 @@ partial class ChronoJumpWindow
 	{
 		previousJumpRjType = currentJumpRjType;
 
-		if(extra_window_radio_jump_rj_more.Active) {
-			jumpsRjMoreWin = JumpsRjMoreWindow.Show(app1, true, currentJumpRjType.Name);
-			jumpsRjMoreWin.Button_accept.Clicked += new EventHandler(on_more_jumps_rj_accepted);
-			jumpsRjMoreWin.Button_cancel.Clicked += new EventHandler(on_more_jumps_rj_cancelled);
-			jumpsRjMoreWin.Button_selected.Clicked += new EventHandler(on_more_jumps_rj_draw_image_test);
-		}
+		jumpsRjMoreWin = JumpsRjMoreWindow.Show(app1, true);
+		jumpsRjMoreWin.Button_accept.Clicked += new EventHandler(on_more_jumps_rj_accepted);
+		jumpsRjMoreWin.Button_cancel.Clicked += new EventHandler(on_more_jumps_rj_cancelled);
+		jumpsRjMoreWin.Button_selected.Clicked += new EventHandler(on_more_jumps_rj_update_test);
 	}
 
 
 	private void extra_window_jumps_initialize(JumpType myJumpType) 
 	{
-		extra_window_jumps_label_selected.Text = "<b>" + Catalog.GetString(myJumpType.Name) + "</b>";
-		extra_window_jumps_label_selected.UseMarkup = true; 
 		currentEventType = myJumpType;
 		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
 		bool hasOptions = false;
@@ -1194,7 +1137,7 @@ partial class ChronoJumpWindow
 		} else 
 			extra_window_showTechniqueArmsData(false, false); //visible, sensitive
 		
-		extra_window_jumps_spinbutton_weight.Value = extra_window_jumps_weight;
+		extra_window_jumps_spinbutton_weight.Value = 20;
 		extra_window_jumps_spinbutton_fall.Value = extra_window_jumps_fall;
 		if (extra_window_jumps_option == "Kg") {
 			extra_window_jumps_radiobutton_kg.Active = true;
@@ -1215,8 +1158,6 @@ partial class ChronoJumpWindow
 	
 	private void extra_window_jumps_rj_initialize(JumpType myJumpType) 
 	{
-		extra_window_jumps_rj_label_selected.Text = "<b>" + Catalog.GetString(myJumpType.Name) + "</b>";
-		extra_window_jumps_rj_label_selected.UseMarkup = true; 
 		currentEventType = myJumpType;
 		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
 		bool hasOptions = false;
@@ -1286,14 +1227,18 @@ partial class ChronoJumpWindow
 		SqlitePreferences.Update("allowFinishRjAfterTime", checkbutton_allow_finish_rj_after_time.Active.ToString(), false);
 	}
 
-	private void on_more_jumps_draw_image_test (object o, EventArgs args) {
+	private void on_more_jumps_update_test (object o, EventArgs args) {
 		currentEventType = new JumpType(jumpsMoreWin.SelectedEventName);
-		changeTestImage(currentEventType.Type.ToString(), currentEventType.Name, currentEventType.ImageFileName);
+		string jumpTranslatedName = Util.FindOnArray(':',1,2, jumpsMoreWin.SelectedEventName, selectJumpsString);
+		
+		combo_select_jumps.Active = UtilGtk.ComboMakeActive(combo_select_jumps, jumpTranslatedName);	
 	}
 	
-	private void on_more_jumps_rj_draw_image_test (object o, EventArgs args) {
+	private void on_more_jumps_rj_update_test (object o, EventArgs args) {
 		currentEventType = new JumpType(jumpsRjMoreWin.SelectedEventName);
-		changeTestImage(currentEventType.Type.ToString(), currentEventType.Name, currentEventType.ImageFileName);
+		string jumpTranslatedName = Util.FindOnArray(':',1,2, jumpsRjMoreWin.SelectedEventName, selectJumpsRjString);
+		
+		combo_select_jumps_rj.Active = UtilGtk.ComboMakeActive(combo_select_jumps_rj, jumpTranslatedName);	
 	}
 	
 	//used from the dialogue "jumps more"
@@ -1301,21 +1246,9 @@ partial class ChronoJumpWindow
 	{
 		jumpsMoreWin.Button_accept.Clicked -= new EventHandler(on_more_jumps_accepted);
 		
-		currentJumpType = new JumpType(
-				//jumpsMoreWin.SelectedJumpType,
-				jumpsMoreWin.SelectedEventName, //type of jump
-								//SelectedEventType would be: jump, or run, ...
-				jumpsMoreWin.SelectedStartIn,
-				jumpsMoreWin.SelectedExtraWeight,
-				false,		//isRepetitive
-				false,		//jumpsLimited (false, because is not repetitive)
-				0,		//limitValue
-				false,		//unlimited
-				jumpsMoreWin.SelectedDescription,
-				SqliteEvent.GraphLinkSelectFileName("jump", jumpsMoreWin.SelectedEventName)
-				);
-	
-		extra_window_jumps_toggle_desired_button_on_toolbar(currentJumpType);
+		currentJumpType = new JumpType(jumpsMoreWin.SelectedEventName);
+
+		extra_window_jumps_initialize(currentJumpType);
 		
 		//destroy the win for not having updating problems if a new jump type is created
 		//jumpsMoreWin = null; //don't work
@@ -1327,21 +1260,9 @@ partial class ChronoJumpWindow
 	{
 		jumpsRjMoreWin.Button_accept.Clicked -= new EventHandler(on_more_jumps_rj_accepted);
 
-		currentJumpRjType = new JumpType(
-				//jumpsRjMoreWin.SelectedJumpType,
-				jumpsRjMoreWin.SelectedEventName,
-				jumpsRjMoreWin.SelectedStartIn,
-				jumpsRjMoreWin.SelectedExtraWeight,
-				true,		//isRepetitive
-				jumpsRjMoreWin.SelectedLimited,
-				jumpsRjMoreWin.SelectedLimitedValue,
-				jumpsRjMoreWin.SelectedUnlimited,
-				jumpsRjMoreWin.SelectedDescription,
-				SqliteEvent.GraphLinkSelectFileName("jumpRj", jumpsRjMoreWin.SelectedEventName)
-				);
-
+		currentJumpRjType = new JumpType(jumpsRjMoreWin.SelectedEventName);
 		
-		extra_window_jumps_rj_toggle_desired_button_on_toolbar(currentJumpRjType);
+		extra_window_jumps_rj_initialize(currentJumpRjType);
 	
 		//destroy the win for not having updating problems if a new jump type is created
 		jumpsRjMoreWin.Destroy();
@@ -1351,49 +1272,15 @@ partial class ChronoJumpWindow
 	private void on_more_jumps_cancelled (object o, EventArgs args) 
 	{
 		currentJumpType = previousJumpType;
-		extra_window_jumps_toggle_desired_button_on_toolbar(currentJumpType);
+		extra_window_jumps_initialize(currentJumpType);
 	}
 	
 	private void on_more_jumps_rj_cancelled (object o, EventArgs args) 
 	{
 		currentJumpRjType = previousJumpRjType;
-		extra_window_jumps_rj_toggle_desired_button_on_toolbar(currentJumpRjType);
+		extra_window_jumps_rj_initialize(currentJumpRjType);
 	}
 	
-	private void extra_window_jumps_toggle_desired_button_on_toolbar(JumpType type) {
-		if(type.Name == "Free") extra_window_radio_jump_free.Active = true;
-		else if(type.Name == "SJ") extra_window_radio_jump_sj.Active = true;
-		else if(type.Name == "SJl") extra_window_radio_jump_sjl.Active = true;
-		else if(type.Name == "CMJ") extra_window_radio_jump_cmj.Active = true;
-		else if(type.Name == "CMJl") extra_window_radio_jump_cmjl.Active = true;
-		else if(type.Name == "slCMJ") extra_window_radio_jump_slcmj.Active = true;
-		else if(type.Name == "ABK") extra_window_radio_jump_abk.Active = true;
-//		else if(type.Name == "DJ") extra_window_radio_jump_dj.Active = true;
-		else if(type.Name == "Rocket") extra_window_radio_jump_rocket.Active = true;
-		else if(type.Name == Constants.TakeOffName) extra_window_radio_jump_takeoff.Active = true;
-		else {
-			//don't do this:
-			//extra_window_radio_jump_more.Active = true;
-			//because it will be a loop
-			//only do:
-			extra_window_jumps_initialize(type);
-		}
-	}
-
-	private void extra_window_jumps_rj_toggle_desired_button_on_toolbar(JumpType type) {
-		if(type.Name == "RJ(j)") extra_window_radio_jump_rj_j.Active = true;
-		else if(type.Name == "RJ(t)") extra_window_radio_jump_rj_t.Active = true;
-		else if(type.Name == "RJ(unlimited)") extra_window_radio_jump_rj_unlimited.Active = true;
-		else if(type.Name == "RJ(hexagon)") extra_window_radio_jump_rj_hexagon.Active = true;
-		else {
-			//don't do this:
-			//extra_window_radio_jump_more.Active = true;
-			//because it will be a loop
-			//only do:
-			extra_window_jumps_rj_initialize(type);
-		}
-	}
-
 	private void extra_window_showWeightData (JumpType myJumpType, bool show) {
 		if(myJumpType.IsRepetitive) {
 			extra_window_jumps_rj_label_weight.Visible = show;
@@ -1537,13 +1424,12 @@ public class JumpsMoreWindow : EventMoreWindow
 	private bool selectedStartIn;
 	private bool selectedExtraWeight;
 
-	public JumpsMoreWindow (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow) {
+	public JumpsMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
-		this.selectedTestOnMainWindow = selectedTestOnMainWindow;
 		
 		if(!testOrDelete)
 			jumps_runs_more.Title = Catalog.GetString("Delete test type defined by user");
@@ -1559,10 +1445,10 @@ public class JumpsMoreWindow : EventMoreWindow
 		initializeThings();
 	}
 	
-	static public JumpsMoreWindow Show (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow)
+	static public JumpsMoreWindow Show (Gtk.Window parent, bool testOrDelete)
 	{
 		if (JumpsMoreWindowBox == null) {
-			JumpsMoreWindowBox = new JumpsMoreWindow (parent, testOrDelete, selectedTestOnMainWindow);
+			JumpsMoreWindowBox = new JumpsMoreWindow (parent, testOrDelete);
 		}
 		JumpsMoreWindowBox.jumps_runs_more.Show ();
 		
@@ -1583,6 +1469,11 @@ public class JumpsMoreWindow : EventMoreWindow
 	{
 		//select data without inserting an "all jumps", without filter, and not obtain only name of jump
 		string [] myJumpTypes = SqliteJumpType.SelectJumpTypes("", "", false);
+
+		//remove typesTranslated
+		typesTranslated = new String [myJumpTypes.Length];
+		int count = 0;
+
 		foreach (string myType in myJumpTypes) {
 			string [] myStringFull = myType.Split(new char[] {':'});
 			if(myStringFull[2] == "1") {
@@ -1604,11 +1495,14 @@ public class JumpsMoreWindow : EventMoreWindow
 			if(testOrDelete || ! tempType.IsPredefined)
 				store.AppendValues (
 						//myStringFull[0], //don't display de uniqueID
-						myStringFull[1],	//name 
+						Catalog.GetString(myStringFull[1]),	//name (translated)
 						myStringFull[2], 	//startIn
 						myStringFull[3], 	//weight
 						description
 						);
+
+			//create typesTranslated
+			typesTranslated [count++] = myStringFull[1] + ":" + Catalog.GetString(myStringFull[1]);
 		}	
 	}
 
@@ -1621,7 +1515,10 @@ public class JumpsMoreWindow : EventMoreWindow
 		selectedDescription = "";
 
 		if (((TreeSelection)o).GetSelected(out model, out iter)) {
-			selectedEventName = (string) model.GetValue (iter, 0);
+			string translatedName = (string) model.GetValue (iter, 0);
+			//get name in english
+			selectedEventName = Util.FindOnArray(':', 1, 0, translatedName, typesTranslated);
+			
 			if( (string) model.GetValue (iter, 1) == Catalog.GetString("Yes") ) {
 				selectedStartIn = true;
 			}
@@ -1650,8 +1547,10 @@ public class JumpsMoreWindow : EventMoreWindow
 		TreeIter iter;
 
 		if (tv.Selection.GetSelected (out model, out iter)) {
-			//put selection in selected
-			selectedEventName = (string) model.GetValue (iter, 0);
+			string translatedName = (string) model.GetValue (iter, 0);
+			//get name in english
+			selectedEventName = Util.FindOnArray(':', 1, 0, translatedName, typesTranslated);
+			
 			if( (string) model.GetValue (iter, 1) == Catalog.GetString("Yes") ) {
 				selectedStartIn = true;
 			}
@@ -1667,6 +1566,11 @@ public class JumpsMoreWindow : EventMoreWindow
 	
 	protected override void deleteTestLine() {
 		SqliteJumpType.Delete(Constants.JumpTypeTable, selectedEventName, false);
+		
+		//delete from typesTranslated
+		string row = Util.FindOnArray(':',0, -1, selectedEventName, typesTranslated);
+		Log.WriteLine("row " + row);
+		typesTranslated = Util.DeleteString(typesTranslated, row);
 	}
 
 	protected override string [] findTestTypesInSessions() {
@@ -1730,14 +1634,13 @@ public class JumpsRjMoreWindow : EventMoreWindow
 	private double selectedLimitedValue;
 	private bool selectedUnlimited;
 	
-	public JumpsRjMoreWindow (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow) {
+	public JumpsRjMoreWindow (Gtk.Window parent, bool testOrDelete) {
 		//the glade window is the same as jumps_more
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
-		this.selectedTestOnMainWindow = selectedTestOnMainWindow;
 		
 		if(!testOrDelete)
 			jumps_runs_more.Title = Catalog.GetString("Delete test type defined by user");
@@ -1757,10 +1660,10 @@ public class JumpsRjMoreWindow : EventMoreWindow
 		initializeThings();
 	}
 	
-	static public JumpsRjMoreWindow Show (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow)
+	static public JumpsRjMoreWindow Show (Gtk.Window parent, bool testOrDelete)
 	{
 		if (JumpsRjMoreWindowBox == null) {
-			JumpsRjMoreWindowBox = new JumpsRjMoreWindow (parent, testOrDelete, selectedTestOnMainWindow);
+			JumpsRjMoreWindowBox = new JumpsRjMoreWindow (parent, testOrDelete);
 		}
 		JumpsRjMoreWindowBox.jumps_runs_more.Show ();
 		
@@ -1778,11 +1681,16 @@ public class JumpsRjMoreWindow : EventMoreWindow
 		tv.AppendColumn ( Catalog.GetString ("Extra weight"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Description"), new CellRendererText(), "text", count++);
 	}
-	
+
 	protected override void fillTreeView (Gtk.TreeView tv, TreeStore store) 
 	{
 		//select data without inserting an "all jumps", and not obtain only name of jump
 		string [] myJumpTypes = SqliteJumpType.SelectJumpRjTypes("", false);
+
+		//remove typesTranslated
+		typesTranslated = new String [myJumpTypes.Length];
+		int count = 0;
+
 		foreach (string myType in myJumpTypes) {
 			string [] myStringFull = myType.Split(new char[] {':'});
 			if(myStringFull[2] == "1") {
@@ -1822,13 +1730,16 @@ public class JumpsRjMoreWindow : EventMoreWindow
 			if(testOrDelete || ! tempType.IsPredefined)
 				store.AppendValues (
 						//myStringFull[0], //don't display de uniqueID
-						myStringFull[1],	//name 
+						Catalog.GetString(myStringFull[1]),	//name (translated)
 						myLimiter,		//jumps or seconds		
 						myLimiterValue,		//? or exact value
 						myStringFull[2], 	//startIn
 						myStringFull[3], 	//weight
 						description
 						);
+
+			//create typesTranslated
+			typesTranslated [count++] = myStringFull[1] + ":" + Catalog.GetString(myStringFull[1]);
 		}	
 	}
 
@@ -1845,7 +1756,9 @@ public class JumpsRjMoreWindow : EventMoreWindow
 		selectedDescription = "";
 
 		if (((TreeSelection)o).GetSelected(out model, out iter)) {
-			selectedEventName = (string) model.GetValue (iter, 0);
+			string translatedName = (string) model.GetValue (iter, 0);
+			//get name in english
+			selectedEventName = Util.FindOnArray(':', 1, 0, translatedName, typesTranslated);
 			
 			if( (string) model.GetValue (iter, 1) == Catalog.GetString("Unlimited") ) {
 				selectedUnlimited = true;
@@ -1893,7 +1806,9 @@ public class JumpsRjMoreWindow : EventMoreWindow
 		TreeIter iter;
 
 		if (tv.Selection.GetSelected (out model, out iter)) {
-			selectedEventName = (string) model.GetValue (iter, 0);
+			string translatedName = (string) model.GetValue (iter, 0);
+			//get name in english
+			selectedEventName = Util.FindOnArray(':', 1, 0, translatedName, typesTranslated);
 			
 			if( (string) model.GetValue (iter, 1) == Catalog.GetString("Unlimited") ) {
 				selectedUnlimited = true;
@@ -1928,6 +1843,10 @@ public class JumpsRjMoreWindow : EventMoreWindow
 	
 	protected override void deleteTestLine() {
 		SqliteJumpType.Delete(Constants.JumpRjTypeTable, selectedEventName, false);
+		
+		//delete from typesTranslated
+		string row = Util.FindOnArray(':',0, -1, selectedEventName, typesTranslated);
+		typesTranslated = Util.DeleteString(typesTranslated, row);
 	}
 	
 	protected override string [] findTestTypesInSessions() {
