@@ -1771,19 +1771,57 @@ public class PersonAddModifyWindow
 	
 }
 
+public class PersonAddMultipleTable {
+	public string name;
+	public bool maleOrFemale;
+	public double weight;
+
+	public PersonAddMultipleTable(string name, bool maleOrFemale, double weight) {
+		this.name = name;
+		this.maleOrFemale = maleOrFemale;
+		this.weight = weight;
+	}
+
+	~PersonAddMultipleTable() {}
+}
+
 //new persons multiple (infinite)
 public class PersonAddMultipleWindow {
 	
 	[Widget] Gtk.Window person_multiple_infinite;
+		
+	[Widget] Gtk.Notebook notebook;
+	
+	[Widget] Gtk.RadioButton radio_csv;
+	[Widget] Gtk.RadioButton radio_manually;
+	[Widget] Gtk.Box hbox_csv;
+	[Widget] Gtk.Box hbox_manually;
+	[Widget] Gtk.SpinButton spin_manually;
+	[Widget] Gtk.Button button_manually_created;
+	
+	[Widget] Gtk.Image image_csv_headers;
+	[Widget] Gtk.Image image_csv_noheaders;
+	[Widget] Gtk.Image image_csv_headers_help;
+	[Widget] Gtk.Image image_csv_noheaders_help;
+	
+	[Widget] Gtk.CheckButton check_headers;
+	[Widget] Gtk.Button button_csv_load;
+	[Widget] Gtk.Button button_csv_help;
+	
+	[Widget] Gtk.Label label_csv_help;
 
+	//use this to read/write table
 	ArrayList entries;
 	ArrayList radiosM;
 	ArrayList radiosF;
 	ArrayList spins;
-	int rows;
 	
+	int rows;
+	bool created_table;
+	
+	[Widget] Gtk.ScrolledWindow scrolledwindow;
 	[Widget] Gtk.Table table_main;
-	[Widget] Gtk.Label label_sport_stuff;
+	[Widget] Gtk.Label label_message;
 	
 	[Widget] Gtk.Button button_accept;
 	
@@ -1796,6 +1834,8 @@ public class PersonAddMultipleWindow {
 	string errorExistsString;
 	string errorWeightString;
 	string errorRepeatedEntryString;
+	string tableAlreadyCreatedString = Catalog.GetString("Table has already been created.");
+
 	
 	PersonAddMultipleWindow (Gtk.Window parent, Session currentSession) {
 		Glade.XML gladeXML;
@@ -1809,13 +1849,14 @@ public class PersonAddMultipleWindow {
 		this.currentSession = currentSession;
 	}
 	
-	static public PersonAddMultipleWindow Show (Gtk.Window parent, Session currentSession, int rows)
+	static public PersonAddMultipleWindow Show (Gtk.Window parent, Session currentSession)
 	{
 		if (PersonAddMultipleWindowBox == null) {
 			PersonAddMultipleWindowBox = new PersonAddMultipleWindow (parent, currentSession);
 		}
-		PersonAddMultipleWindowBox.rows = rows;
-		PersonAddMultipleWindowBox.create ();
+		
+		PersonAddMultipleWindowBox.putNonStandardIcons ();
+		PersonAddMultipleWindowBox.created_table = false;
 
 		PersonAddMultipleWindowBox.person_multiple_infinite.Show ();
 		
@@ -1833,8 +1874,157 @@ public class PersonAddMultipleWindow {
 		PersonAddMultipleWindowBox.person_multiple_infinite.Hide();
 		PersonAddMultipleWindowBox = null;
 	}
+		
+	void putNonStandardIcons() {
+		Pixbuf pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVHeadersIcon);
+		image_csv_headers.Pixbuf = pixbuf;
+		image_csv_headers_help.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameCSVNoHeadersIcon);
+		image_csv_noheaders.Pixbuf = pixbuf;
+		image_csv_noheaders_help.Pixbuf = pixbuf;
+	}
+
+	void on_check_headers_toggled (object obj, EventArgs args) {
+		image_csv_headers.Visible = (check_headers.Active == true);
+		image_csv_noheaders.Visible = (check_headers.Active == false);
+	}
 	
-	void create() {
+	void on_radio_csv_toggled (object obj, EventArgs args) {
+		if(radio_csv.Active) {
+			hbox_csv.Sensitive = true;
+			hbox_manually.Sensitive = false;
+		}
+	}
+	void on_radio_manually_toggled (object obj, EventArgs args) {
+		if(radio_manually.Active) {
+			hbox_csv.Sensitive = false;
+			hbox_manually.Sensitive = true;
+		}
+	}
+		
+	void on_button_csv_load_clicked (object obj, EventArgs args) 
+	{
+		if(created_table) {
+			label_message.Text = tableAlreadyCreatedString;
+			label_message.Visible = true;
+			return;
+		}
+
+		Gtk.FileChooserDialog fc=
+			new Gtk.FileChooserDialog(Catalog.GetString("Select CSV file"),
+					null,
+					FileChooserAction.Open,
+					Catalog.GetString("Cancel"),ResponseType.Cancel,
+					Catalog.GetString("Load"),ResponseType.Accept
+					);
+
+		fc.Filter = new FileFilter();
+		fc.Filter.AddPattern("*.csv");
+		fc.Filter.AddPattern("*.CSV");
+
+		ArrayList array = new ArrayList();
+		if (fc.Run() == (int)ResponseType.Accept) { 
+			System.IO.FileStream file=System.IO.File.OpenRead(fc.Filename); 
+
+			List<string> columns = new List<string>();
+			using (var reader = new CsvFileReader(fc.Filename))
+			{
+				int row = 0;
+				while (reader.ReadRow(columns))
+				{
+					string name = "";
+					bool maleOrFemale = true;
+					double weight = 0;
+					int col = 0;
+					foreach(string str in columns) {
+						//if headers are active do not process first row
+						//do not process this first row because weight can be a string
+						if(check_headers.Active && row == 0)
+							continue;
+						
+						Log.Write(":" + str);
+						if(col == 0)
+							name = str;
+						else if(col == 1) {
+							//female symbols
+							if(str == "0" || str == "f" || str == "F")
+								maleOrFemale = false;
+						}
+						else if(col == 2) {
+							try {
+								weight = Convert.ToDouble(Util.ChangeDecimalSeparator(str));
+							} catch {
+								string message = Catalog.GetString("Error importing data.");
+								if( ! check_headers.Active && row == 0)
+									message += "\n" + Catalog.GetString("Seems there's a header row and you have not marked it.");
+
+								new DialogMessage(Constants.MessageTypes.WARNING, message);
+
+								file.Close(); 
+								//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
+								fc.Destroy();
+
+								return;
+							}
+						}
+						col ++;
+					}
+					//if headers are active do not add first row
+					if( ! (check_headers.Active && row == 0) ) {
+						PersonAddMultipleTable pamt = new PersonAddMultipleTable( name, maleOrFemale, weight);
+						array.Add(pamt);
+					}
+					
+					row ++;
+					Log.Write("\n");
+				}
+			}
+
+			file.Close(); 
+
+			rows = array.Count;
+			createEmptyTable();
+			fillTableFromCSV(array);
+		} 
+
+		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
+		fc.Destroy();
+	}
+	
+	
+	void on_button_csv_help_clicked (object obj, EventArgs args) 
+	{
+		label_csv_help.Text =
+			"<b>" + Catalog.GetString("Import persons from an spreadsheet. Eg. Excel, LibreOffice, Google Drive.") + "</b>\n\n" +
+			Catalog.GetString("Open the spreadsheet with the persons data to be added.") + "\n\n" +
+			Catalog.GetString("Spreadsheed need to have this structure:") + "\n" +
+			" - " + Catalog.GetString("First column should be full name of each person.") + "\n" +
+			" - " + Catalog.GetString("Second column should be the gender of the person: Use the values 1/0, or m/f, or M/F to differentiate between male and female.") + "\n" +
+			" - " + Catalog.GetString("Third column should be the weight in Kg.");
+
+		label_csv_help.UseMarkup = true;
+		notebook.CurrentPage = 1;
+	}
+	
+	void on_button_csv_help_close_clicked (object obj, EventArgs args) {
+		notebook.CurrentPage = 0;
+	}
+	
+	void on_button_manually_create_clicked (object obj, EventArgs args) 
+	{
+		if(created_table) {
+			label_message.Text = tableAlreadyCreatedString;
+			label_message.Visible = true;
+			return;
+		}
+
+		rows = Convert.ToInt32(spin_manually.Value);
+
+		createEmptyTable();
+	}
+
+	void createEmptyTable() {
 		entries = new ArrayList();
 		radiosM = new ArrayList();
 		radiosF = new ArrayList();
@@ -1856,20 +2046,26 @@ public class PersonAddMultipleWindow {
 		weightLabel.Show();
 		nameLabel.Show();
 		sexLabel.Show();
-		
+	
+		uint padding = 4;	
 
-		table_main.Attach (nameLabel, (uint) 1, (uint) 2, 0, 1);
-		table_main.Attach (sexLabel, (uint) 2, (uint) 3, 0, 1);
-		table_main.Attach (weightLabel, (uint) 3, (uint) 4, 0, 1);
+		table_main.Attach (nameLabel, (uint) 1, (uint) 2, 0, 1, 
+				Gtk.AttachOptions.Fill | Gtk.AttachOptions.Expand , Gtk.AttachOptions.Shrink, padding, padding);
+		table_main.Attach (sexLabel, (uint) 2, (uint) 3, 0, 1, 
+				Gtk.AttachOptions.Shrink, Gtk.AttachOptions.Shrink, padding, padding);
+		table_main.Attach (weightLabel, (uint) 3, (uint) 4, 0, 1, 
+				Gtk.AttachOptions.Shrink, Gtk.AttachOptions.Shrink, padding, padding);
 
 		for (int count=1; count <= rows; count ++) {
 			Gtk.Label myLabel = new Gtk.Label((count).ToString());
-			table_main.Attach (myLabel, (uint) 0, (uint) 1, (uint) count, (uint) count +1);
+			table_main.Attach (myLabel, (uint) 0, (uint) 1, (uint) count, (uint) count +1, 
+					Gtk.AttachOptions.Shrink, Gtk.AttachOptions.Shrink, padding, padding);
 			myLabel.Show();
 			//labels.Add(myLabel);
 
 			Gtk.Entry myEntry = new Gtk.Entry();
-			table_main.Attach (myEntry, (uint) 1, (uint) 2, (uint) count, (uint) count +1);
+			table_main.Attach (myEntry, (uint) 1, (uint) 2, (uint) count, (uint) count +1, 
+					Gtk.AttachOptions.Fill | Gtk.AttachOptions.Expand , Gtk.AttachOptions.Shrink, padding, padding);
 			myEntry.Show();
 			entries.Add(myEntry);
 
@@ -1886,11 +2082,13 @@ public class PersonAddMultipleWindow {
 			sexBox.PackStart(myRadioM, false, false, 4);
 			sexBox.PackStart(myRadioF, false, false, 4);
 			sexBox.Show();
-			table_main.Attach (sexBox, (uint) 2, (uint) 3, (uint) count, (uint) count +1);
+			table_main.Attach (sexBox, (uint) 2, (uint) 3, (uint) count, (uint) count +1, 
+					Gtk.AttachOptions.Shrink, Gtk.AttachOptions.Shrink, padding, padding);
 
 
 			Gtk.SpinButton mySpin = new Gtk.SpinButton(0, 300, .1);
-			table_main.Attach (mySpin, (uint) 3, (uint) 4, (uint) count, (uint) count +1);
+			table_main.Attach (mySpin, (uint) 3, (uint) 4, (uint) count, (uint) count +1, 
+					Gtk.AttachOptions.Shrink, Gtk.AttachOptions.Shrink, padding, padding);
 			mySpin.Show();
 			spins.Add(mySpin);
 		}
@@ -1906,10 +2104,30 @@ public class PersonAddMultipleWindow {
 		if(sportStuffString.Length > 0)
 			sportStuffString = Catalog.GetString("Persons will be created with default session values") + 
 				":\n" + sportStuffString;
-		label_sport_stuff.Text = sportStuffString;
-		label_sport_stuff.UseMarkup = true;
+		label_message.Text = sportStuffString;
+		label_message.UseMarkup = true;
+		label_message.Visible = true;
 
 		table_main.Show();
+		scrolledwindow.Visible = true;
+		notebook.CurrentPage = 0;
+			
+		//once loaded table cannot be created again
+		//don't do this: it crashes
+		//button_manually_created.Sensitive = false;
+		//do this:
+		created_table = true;
+	}
+		
+	void fillTableFromCSV(ArrayList array) {
+		int i = 0;
+		foreach(PersonAddMultipleTable pamt in array) {
+			((Gtk.Entry)entries[i]).Text = pamt.name;
+			((Gtk.RadioButton)radiosM[i]).Active = pamt.maleOrFemale;
+			((Gtk.RadioButton)radiosF[i]).Active = ! pamt.maleOrFemale;
+			((Gtk.SpinButton)spins[i]).Value = pamt.weight;
+			i++;
+		}
 	}
 
 	void on_button_accept_clicked (object o, EventArgs args)
