@@ -120,19 +120,19 @@ public class Report : ExportSession
 			myPersons = SqlitePersonSession.SelectCurrentSessionPersons(sessionID);
 		}
 		if(ShowSimpleJumps) {
-			myJumps= SqliteJump.SelectJumps(sessionID, -1, "", "");
+			myJumps= SqliteJump.SelectJumps(false, sessionID, -1, "", "");
 		}
 		if(ShowReactiveJumps) {
 			myJumpsRj = SqliteJumpRj.SelectJumps(sessionID, -1, "", "");
 		}
 		if(ShowSimpleRuns) {
-			myRuns= SqliteRun.SelectRuns(sessionID, -1, "");
+			myRuns= SqliteRun.SelectRuns(false, sessionID, -1, "");
 		}
 		if (ShowIntervalRuns) {
 			myRunsInterval = SqliteRunInterval.SelectRuns(sessionID, -1, "");
 		}
 		if(ShowReactionTimes) {
-			myReactionTimes= SqliteReactionTime.SelectReactionTimes(sessionID, -1);
+			myReactionTimes= SqliteReactionTime.SelectReactionTimes(false, sessionID, -1);
 		}
 		if(ShowPulses) {
 			myPulses= SqlitePulse.SelectPulses(sessionID, -1);
