@@ -52,11 +52,13 @@ class SqliteEncoder : Sqlite
 			"url TEXT, " +
 			"time INT, " +
 			"minHeight INT, " +
-			"smooth FLOAT, " +  	//unused. since 1.3.7 is on preferences
 			"description TEXT, " +
-			"future1 TEXT, " +	//works as status: "active", "inactive"
-			"future2 TEXT, " +	//URL of video of signals
-			"future3 TEXT )";	//Inverted (encoder is upside down) only on signals
+			"status TEXT, " +	//"active", "inactive"
+			"videoURL TEXT, " +	//URL of video of signals
+			"encoderConfiguration TEXT, " +	//text separated by ':'
+		       	"future1 TEXT, " + 
+		       	"future2 TEXT, " + 
+		       	"future3 TEXT )";
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -73,16 +75,18 @@ class SqliteEncoder : Sqlite
 			es.uniqueID = "NULL";
 
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderTable +  
-				" (uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, signalOrCurve, filename, url, time, minHeight, smooth, description, future1, future2, future3)" +
-				" VALUES (" + es.uniqueID + ", " +
-				es.personID + ", " + es.sessionID + ", " +
-				es.exerciseID + ", '" + es.eccon + "', '" +
-				es.laterality + "', '" + es.extraWeight + "', '" +
-				es.signalOrCurve + "', '" + es.filename + "', '" +
-				es.url + "', " + es.time + ", " + es.minHeight + ", " +
-				Util.ConvertToPoint(es.smooth) + ", '" + es.description + "', 'active', " + 
-				"'','" + 		//future2 url (this is stored later)
-			       	es.future3 + "')" ;	//future3 inverted?
+			" (uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, " + 
+			"signalOrCurve, filename, url, time, minHeight, description, status, " +
+			"videoURL, encoderConfiguration, future1, future2, future3)" +
+			" VALUES (" + es.uniqueID + ", " +
+			es.personID + ", " + es.sessionID + ", " +
+			es.exerciseID + ", '" + es.eccon + "', '" +
+			es.laterality + "', '" + es.extraWeight + "', '" +
+			es.signalOrCurve + "', '" + es.filename + "', '" +
+			es.url + "', " + es.time + ", " + es.minHeight + ", '" + es.description + 
+			"', '" + es.status + "', '" + es.videoURL + "', '" + 
+			es.encoderConfiguration.ToString(":",true) + "', '" + 
+			es.future1 + "', '" + es.future2 + "', '" + es.future3 + "')";
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -118,8 +122,10 @@ class SqliteEncoder : Sqlite
 				"', url = '" + es.url +
 				"', time = " + es.time +
 				", minHeight = " + es.minHeight +
-				", smooth = " + Util.ConvertToPoint(es.smooth) +	//unused. in 1.3.7 is on preferences
 				", description = '" + es.description + 
+				"', status = '" + es.status + 
+				"', videoURL = '" + es.videoURL + 
+				"', encoderConfiguration = '" + es.encoderConfiguration.ToString(":",true) + 
 				"', future1 = '" + es.future1 + 
 				"', future2 = '" + es.future2 + 
 				"', future3 = '" + es.future3 + 
@@ -138,6 +144,7 @@ class SqliteEncoder : Sqlite
 	//pass uniqueID==-1 and personID, sessionID, signalOrCurve values, and will return some records
 	//personID can be -1 to get all on that session
 	//sessionID can be -1 to get all sessions
+	//signalOrCurve can be "all"
 	public static ArrayList Select (bool dbconOpened, 
 			int uniqueID, int personID, int sessionID, string signalOrCurve, bool onlyActive)
 	{
@@ -155,19 +162,26 @@ class SqliteEncoder : Sqlite
 		string selectStr = "";
 		if(uniqueID != -1)
 			selectStr = Constants.EncoderTable + ".uniqueID = " + uniqueID;
-		else
-			selectStr = personIDStr + sessionIDStr + 
-			" signalOrCurve = '" + signalOrCurve + "'";
+		else {
+			if(signalOrCurve == "all")
+				selectStr = personIDStr + sessionIDStr;
+			else
+				selectStr = personIDStr + sessionIDStr + " signalOrCurve = '" + signalOrCurve + "'";
+		}
+
+		string andString = "";
+		if(selectStr != "")
+			andString = " AND ";
 
 		string onlyActiveString = "";
 		if(onlyActive)
-			onlyActiveString = " AND " + Constants.EncoderTable + ".future1 = 'active' ";
+			onlyActiveString = " AND " + Constants.EncoderTable + ".status = 'active' ";
 
 		dbcmd.CommandText = "SELECT " + 
 			Constants.EncoderTable + ".*, " + Constants.EncoderExerciseTable + ".name FROM " + 
 			Constants.EncoderTable  + ", " + Constants.EncoderExerciseTable  + 
 			" WHERE " + selectStr +
-			" AND " + Constants.EncoderTable + ".exerciseID = " + 
+			andString + Constants.EncoderTable + ".exerciseID = " + 
 				Constants.EncoderExerciseTable + ".uniqueID " +
 				onlyActiveString +
 			" ORDER BY substr(filename,-23,19)"; //this contains the date of capture signal
@@ -181,6 +195,13 @@ class SqliteEncoder : Sqlite
 
 		EncoderSQL es = new EncoderSQL();
 		while(reader.Read()) {
+			string [] strFull = reader[15].ToString().Split(new char[] {':'});
+			EncoderConfiguration econf = new EncoderConfiguration(
+				(Constants.EncoderConfigurationNames) 
+				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
+			econf.FromSQL(strFull);
+			
+			Log.WriteLine(econf.ToString(":", true));
 			es = new EncoderSQL (
 					reader[0].ToString(),			//uniqueID
 					Convert.ToInt32(reader[1].ToString()),	//personID	
@@ -194,12 +215,14 @@ class SqliteEncoder : Sqlite
 					reader[9].ToString(),			//url
 					Convert.ToInt32(reader[10].ToString()),	//time
 					Convert.ToInt32(reader[11].ToString()),	//minHeight
-					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[12].ToString())), //smooth UNUSED
-					reader[13].ToString(),			//description
-					reader[14].ToString(),			//future1
-					reader[15].ToString(),			//future2
-					reader[16].ToString(),			//future3
-					reader[17].ToString()			//EncoderExercise.name
+					reader[12].ToString(),			//description
+					reader[13].ToString(),			//status
+					reader[14].ToString(),			//videoURL
+					econf,					//encoderConfiguration
+					reader[16].ToString(),			//future1
+					reader[17].ToString(),			//future2
+					reader[18].ToString(),			//future3
+					reader[19].ToString()			//EncoderExercise.name
 					);
 			array.Add (es);
 		}
@@ -218,22 +241,22 @@ class SqliteEncoder : Sqlite
 
 		/* OLD, returns a row for active and a row for inactive at each session	
 		dbcmd.CommandText = 
-			"SELECT count(*), encoder.sessionID, session.name, session.date, encoder.future1 " +
+			"SELECT count(*), encoder.sessionID, session.name, session.date, encoder.status " +
 			" FROM encoder, session, person77 " +
 			" WHERE encoder.personID == " + personID + " AND signalOrCurve == 'curve' AND " + 
 			" encoder.personID == person77.uniqueID AND encoder.sessionID == session.uniqueID " + 
-			" GROUP BY encoder.sessionID, encoder.future1 ORDER BY encoder.sessionID, encoder.future1";
+			" GROUP BY encoder.sessionID, encoder.status ORDER BY encoder.sessionID, encoder.status";
 			*/
 
 		//returns a row for each session where there are active or inactive
 		dbcmd.CommandText = 
 			"SELECT encoder.sessionID, session.name, session.date, " +
-			" SUM(CASE WHEN encoder.future1 = 'active' THEN 1 END) as active, " +
-			" SUM(CASE WHEN encoder.future1 = 'inactive' THEN 1 END) as inactive " + 
+			" SUM(CASE WHEN encoder.status = 'active' THEN 1 END) as active, " +
+			" SUM(CASE WHEN encoder.status = 'inactive' THEN 1 END) as inactive " + 
 			" FROM encoder, session, person77 " +
 			" WHERE encoder.personID == " + personID + " AND signalOrCurve == 'curve' AND " +
 			" encoder.personID == person77.uniqueID AND encoder.sessionID == session.uniqueID " +
-			" GROUP BY encoder.sessionID ORDER BY encoder.sessionID, encoder.future1";
+			" GROUP BY encoder.sessionID ORDER BY encoder.sessionID, encoder.status";
 	
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		
@@ -289,13 +312,13 @@ class SqliteEncoder : Sqlite
 			"ressistance TEXT, " +
 			"description TEXT, " +
 			"future1 TEXT, " +	//speed1RM: speed in m/s at 1RM with decimal point separator '.' ; 0 means undefined
-			"future2 TEXT, " +
-			"future3 TEXT )";
+			"future2 TEXT, " +	//bodyAngle (unused)
+			"future3 TEXT )";	//weightAngle (unused)
 		dbcmd.ExecuteNonQuery();
 	}
 	
 	public static void InsertExercise(bool dbconOpened, string name, int percentBodyWeight, 
-			string ressistance, string description, string speed1RM) //speed1RM decimal point = '.'
+			string ressistance, string description, string speed1RM)	 //speed1RM decimal point = '.'
 	{
 		if(! dbconOpened)
 			dbcon.Open();
@@ -303,7 +326,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.CommandText = "INSERT INTO " + Constants.EncoderExerciseTable +  
 				" (uniqueID, name, percentBodyWeight, ressistance, description, future1, future2, future3)" +
 				" VALUES (NULL, '" + name + "', " + percentBodyWeight + ", '" + 
-				ressistance + "', '" + description + "', '" + speed1RM + "','','')";
+				ressistance + "', '" + description + "', '" + speed1RM + "', '', '')";
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -317,9 +340,39 @@ class SqliteEncoder : Sqlite
 	protected internal static void initializeTableEncoderExercise()
 	{
 		string [] iniEncoderExercises = {
-			//name:percentBodyWeight:ressistance:description:speed1RM
-			"Bench press:0:weight bar::0.185", //González-Badillo, J. 2010. Movement velocity as a measure of loading intensity in resistance training
-			"Squat:100:weight bar::0.31" //González-Badillo, JJ.2000b http://foro.chronojump.org/showthread.php?tid=1288&page=3 
+			//name:percentBodyWeight:ressistance:description:speed1RM:pullAngle:weightAngle
+			"Bench press:0:weight bar::0.185::", //González-Badillo, J. 2010. Movement velocity as a measure of loading intensity in resistance training
+			"Squat:100:weight bar::0.31::" //González-Badillo, JJ.2000b http://foro.chronojump.org/showthread.php?tid=1288&page=3 
+		};
+		
+		foreach(string line in iniEncoderExercises) {
+			string [] parts = line.Split(new char[] {':'});
+			InsertExercise(true, parts[0], Convert.ToInt32(parts[1]), parts[2], parts[3], parts[4]);
+		}
+
+		addEncoderFreeExercise();
+		addEncoderJumpExercise();
+		addEncoderInclinatedExercises();
+	}
+	
+	protected internal static void addEncoderFreeExercise()
+	{
+		bool exists = Sqlite.Exists (true, Constants.EncoderExerciseTable, "Free");
+		if(! exists)
+			InsertExercise(true, "Free", 0, "", "", "");
+	}
+	protected internal static void addEncoderJumpExercise()
+	{
+		bool exists = Sqlite.Exists (true, Constants.EncoderExerciseTable, "Jump");
+		if(! exists)
+			InsertExercise(true, "Jump", 100, "", "", "");
+	}
+	protected internal static void addEncoderInclinatedExercises()
+	{
+		string [] iniEncoderExercises = {
+			//name:percentBodyWeight:ressistance:description:speed1RM:bodyAngle:weightAngle
+			"Inclinated plane:0:machine::::",
+			"Inclinated plane BW:100:machine::::",
 		};
 		
 		foreach(string line in iniEncoderExercises) {
@@ -403,6 +456,23 @@ class SqliteEncoder : Sqlite
 		return array;
 	}
 	
+	//conversion from DB 0.99 to 1.00
+	protected internal static void putEncoderExerciseAnglesAt90() {
+		dbcmd.CommandText = "UPDATE " + Constants.EncoderExerciseTable + 
+			" SET future2 = 90, future3 = 90";
+
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+	}
+	
+	//conversion from DB 1.02 to 1.03
+	protected internal static void removeEncoderExerciseAngles() {
+		dbcmd.CommandText = "UPDATE " + Constants.EncoderExerciseTable + 
+			" SET future2 = '', future3 = ''";
+
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+	}
 	
 	/*
 	 * 1RM stuff
