@@ -339,6 +339,14 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 	
+	public static string ChangeChars(string str, string charIni, string charEnd) 
+	{
+		StringBuilder myStringBuilder = new StringBuilder(str);
+		myStringBuilder.Replace(charIni, charEnd);
+		return myStringBuilder.ToString();
+	}
+
+	
 	public static string GetHeightInCentimeters (string time) {
 		// s = 4.9 * (tv/2)^2
 		double timeAsDouble = Convert.ToDouble(time);
@@ -1160,6 +1168,18 @@ public class Util
 		return uniqueString;
 	}
 	
+	public static string StringArrayToStringWithQuotes (string [] myFullString, string separator) {
+		string uniqueString = "";
+		string sep = "";
+		string quote = "\"";
+		foreach (string myStr in myFullString) {
+			uniqueString += sep + quote + myStr + quote;
+			sep = separator;
+		}
+		return uniqueString;
+	}
+	
+	
 	//to create an string [] of one member
 	public static string [] StringToStringArray (string str) {
 		string [] ret = new string[1];
@@ -1243,14 +1263,19 @@ public class Util
 	/* eg we have an stringArray containing in a row "Letonia, Republica de" and we want to find ID
 	 * 2:Latvia, Republic of:Letonia, Republica de
 	 * we do string myString = Util.FindOnArray(':', 2, 0, "Letonoa, Republica de", stringArray);
+	 * if partToReturn == -1, then return all the string (all the row) 
 	 */
 	public static string FindOnArray(char separator, int partPassed, int partToReturn, string stringPassed, string [] stringArray) 
 	{
 		string foundString = "";
 		foreach(string myString in stringArray) {
 			string [] myStrFull = myString.Split(new char[] {separator});
-			if(myStrFull[partPassed] == stringPassed)
-				foundString = myStrFull[partToReturn];
+			if(myStrFull[partPassed] == stringPassed) {
+				if(partToReturn == -1)
+					foundString = myString;
+				else
+					foundString = myStrFull[partToReturn];
+			}
 
 		}
 		return foundString;
@@ -1430,4 +1455,22 @@ public class Util
 		return pounds * 0.45359237;
 	}
 
+
+	/* 
+	 * used to display correcly strings on R Windows, because it doesn't support accents in plots,
+	 * but it plots correctly the unicode
+	 */
+	public static string ConvertToUnicode(string str) {
+		//http://stackoverflow.com/questions/6348022/escaping-an-unicode-string-using-backslash-notation-in-c-sharp
+		System.Text.StringBuilder sb = new System.Text.StringBuilder();
+		foreach (char c in str)
+		{
+			if (' ' <= c && c <= '~')
+				sb.Append(c);
+			else
+				sb.AppendFormat("\\U{0:X4}", (int)c);
+		}
+		return sb.ToString();
+	}
+
 }
